summaryrefslogtreecommitdiff
path: root/libfat
diff options
context:
space:
mode:
authorhpa <hpa>2004-12-15 20:29:17 +0000
committerhpa <hpa>2004-12-15 20:29:17 +0000
commit77cfe4bb9b00690ab3b87a105eed5c430f97bb18 (patch)
tree83568d4c451d7f11590aee0a6dcf74ee6c1b4a60 /libfat
parent701f75fe81968cf2dccbffbf2f09bf2b04ea4ad6 (diff)
downloadsyslinux-77cfe4bb9b00690ab3b87a105eed5c430f97bb18.tar.gz
Make the CC_IS_OK hack work again.
Change the private pointer in libfat to an intptr_t; we actually use an integer most of the time so an intptr_t is more convenient.
Diffstat (limited to 'libfat')
-rw-r--r--libfat/libfat.h6
-rw-r--r--libfat/libfatint.h4
-rw-r--r--libfat/open.c4
3 files changed, 7 insertions, 7 deletions
diff --git a/libfat/libfatint.h b/libfat/libfatint.h
index 6da47f18..67b67b22 100644
--- a/libfat/libfatint.h
+++ b/libfat/libfatint.h
@@ -36,8 +36,8 @@ enum fat_type {
};
struct libfat_filesystem {
- int (*read)(void *, void *, size_t, libfat_sector_t);
- void *readptr;
+ int (*read)(intptr_t, void *, size_t, libfat_sector_t);
+ intptr_t readptr;
enum fat_type fat_type;
unsigned int clustsize;
diff --git a/libfat/open.c b/libfat/open.c
index 835c336d..a66d21e7 100644
--- a/libfat/open.c
+++ b/libfat/open.c
@@ -23,8 +23,8 @@
#include "ulint.h"
struct libfat_filesystem *
-libfat_open(int (*readfunc)(void *, void *, size_t, libfat_sector_t),
- void *readptr)
+libfat_open(int (*readfunc)(intptr_t, void *, size_t, libfat_sector_t),
+ intptr_t readptr)
{
struct libfat_filesystem *fs = NULL;
struct fat_bootsect *bs;
diff --git a/libfat/libfat.h b/libfat/libfat.h
index b0682279..58bf6b5a 100644
--- a/libfat/libfat.h
+++ b/libfat/libfat.h
@@ -33,7 +33,7 @@ struct libfat_filesystem;
/*
* Open the filesystem. The readfunc is the function to read
* sectors, in the format:
* int readfunc(void *readptr, void *buf, size_t secsize,
* libfat_sector_t secno)
*
* ... where readptr is a private argument.
@@ -41,8 +41,8 @@ struct libfat_filesystem;
* A return value of != secsize is treated as error.
*/
struct libfat_filesystem *
-libfat_open(int (*readfunc)(void *, void *, size_t, libfat_sector_t),
- void *readptr);
+libfat_open(int (*readfunc)(intptr_t, void *, size_t, libfat_sector_t),
+ intptr_t readptr);
void libfat_close(struct libfat_filesystem *);
@@ -33,7 +33,7 @@ struct libfat_filesystem;
* Open the filesystem. The readfunc is the function to read
* sectors, in the format:
- * int readfunc(void *readptr, void *buf, size_t secsize,
+ * int readfunc(intptr_t readptr, void *buf, size_t secsize,
* libfat_sector_t secno)
*